@@ -212,9 +212,8 @@ class SizeableDisk(object):
             all_usebytes = availbytes + needbytes
             all_use = humanreadableSize(all_usebytes)
             raise VirtualDiskError(
-                _("There is not enough space on this device "
-                  "to perform the autopartition") + _(": ") +
-                _("need {need}").format(
+                _("There is not enough space on this device, "
+                  "to perform the autopartition need {need}").format(
                     need=all_use))
 
 
